@@ -734,7 +734,6 @@ static int show_pages(
 	index = page_index;
 	for (i = 1; i <= ymax; i++) {
 		int32_t j;
-		map_t *map;
 		addr_t addr, offset;
 		const size_t sz = sizeof(pagemap_info_buf);
 
@@ -768,11 +767,9 @@ static int show_pages(
 				attr = COLOR_PAIR(BLACK_BLACK);
 				state = '~';
 			} else {
-				off_t offset;
 				map_t *new_map;
 				register pagemap_t pagemap_info;
 
-				addr = g.mem_info.pages[index].addr;
 				new_map = g.mem_info.pages[index].map;
 				/*
 				 *  On a different mapping? If so, slurp up
